==> floodcast-0.0.11.tar.bz2: floodcast-0.0.11/src/server.h <==
/*
    server.h -  Floodcast server socket

    Copyright (c) 2002 by Ryan Cumming
    Copyright (c) 2004 by Stefan Gehn <metz AT gehn.net>

    *************************************************************************
    *                                                                       *
    * This program is free software; you can redistribute it and/or modify  *
    * it under the terms of the GNU General Public License as published by  *
    * the Free Software Foundation; either version 2 of the License, or     *
    * (at your option) any later version.                                   *
    *                                                                       *
    *************************************************************************
*/

#ifndef _SERVER_H
#define _SERVER_H

#include <qptrlist.h>
#include <qserversocket.h>

class MP3Stream;
class QSocket;

// Listens on a given port and emits a signal on a new connection
class IcecastServerSocket : public QServerSocket
{
	Q_OBJECT
	public:
		// Create an IcecastServerSocket listening on
		// a given port
		IcecastServerSocket(int port, QObject * parent = 0, const char * name = 0);

	protected:
		// This is reimplemented from QServerSocket
		// Called when we have a new connection
		void newConnection(int socket);

	signals:
		// Called from newConnection when a new
		// connection is established
		void connection(int socket);
};


// Handles HTTP setup and socket objects
// Transmits data from MP3Stream
class IcecastServer : public QObject
{
	Q_OBJECT
	public:
		// Start an icecast server listening on a given port
		IcecastServer(QObject *parent = 0, const char *name = 0);
		~IcecastServer();

		int maxUsers();
		void setMaxUsers(int max);

		// Restart our encoder object, to let
		// new settings take effect
		void restartEncoder();

		void stop();
		void start();

		// Change the port we're listening on
		// Does not affect current listeners
		void setListenPort(unsigned int port);

		// Cleanly disconnect a user
		void removeSocket(QSocket *);

	signals:
		// Emitted when we have a new listener (after HTTP setup)
		void gainedConnection(QSocket *);
		// Emitted when we've lost a connection
		void lostConnection(QSocket *);
		void statusChange(bool);

	protected slots:
		// Called when client has sent a read event
		void readClient();
		// Called when a socket has unexpectedly died
		void connectionClosed();
		// Called when the encoder has new data for us
		void transmitData(char *, int);
		// Called when our IcecastServerSocket has a
		// new connection
		void addSocket(int);
		// Called when our MP3Stream died unexpectedly
		// Used to shutdown the server for now
		void slotEncoderDied();

	protected:
		// Our server socket (listens for connections)
		IcecastServerSocket *mServerSocket;
		// Our currently active sockets
		QPtrList<QSocket> _sockets;
		// Our encoder wrapper
		MP3Stream *mStream;
		bool mActive;
		unsigned int _max_users;
};

#endif

==> floodcast-0.0.12.tar.bz2: floodcast-0.0.12/src/server.h <==
/*
    server.h -  Floodcast server socket

    Copyright (c) 2002 by Ryan Cumming
    Copyright (c) 2004 by Stefan Gehn <metz AT gehn.net>

    *************************************************************************
    *                                                                       *
    * This program is free software; you can redistribute it and/or modify  *
    * it under the terms of the GNU General Public License as published by  *
    * the Free Software Foundation; either version 2 of the License, or     *
    * (at your option) any later version.                                   *
    *                                                                       *
    *************************************************************************
*/

#ifndef _SERVER_H
#define _SERVER_H

#include <qptrlist.h>
#include <qsocket.h>
#include <qserversocket.h>

class MP3Stream;
class QSocket;
class IcecastServer;

// Listens on a given port and emits a signal on a new connection
class IcecastServerSocket : public QServerSocket
{
	Q_OBJECT
	public:
		// Create an IcecastServerSocket listening on
		// a given port
		IcecastServerSocket(int port, QObject * parent = 0, const char * name = 0);

	protected:
		// This is reimplemented from QServerSocket
		// Called when we have a new connection
		void newConnection(int socket);

	signals:
		// Called from newConnection when a new
		// connection is established
		void connection(int socket);
};



class IcecastClientSocket : public QSocket
{
	Q_OBJECT
	public:
		IcecastClientSocket(int socket, IcecastServer *parent = 0, const char *name = 0);

		Q_LONG IcecastClientSocket::writeBlock(const char *data, Q_ULONG len);
		const QString &userAgent();

	signals:
		void clientDisconnected(IcecastClientSocket *);
		void clientConnected(IcecastClientSocket *);

	protected slots:
		void slotRead();
		void slotConnectionClosed();

	protected:
		bool bSendMeta;
		int mLastMetaData;
		IcecastServer *mServer;
		QString mUserAgent;
		bool bStreaming;
		QCString mLastTitle; // remember title sent to the client last time
};


// Handles HTTP setup and socket objects
// Transmits data from MP3Stream
class IcecastServer : public QObject
{
	Q_OBJECT
	public:
		// Start an icecast server listening on a given port
		IcecastServer(QObject *parent = 0, const char *name = 0);
		~IcecastServer();

		int maxClients();
		void setMaxClients(unsigned int max);
		int connectedClients() { return mClientSockets.count(); };

		// Restart our encoder object, to let
		// new settings take effect
		void restartEncoder();

		void stop();
		void start();

		// Change the port we're listening on
		// Does not affect current listeners
		void setListenPort(unsigned int port);

		// Cleanly disconnect a user
		void removeSocket(IcecastClientSocket *);

		bool isActive() { return mActive; };

		void setTitle(const QString &songtitle);
		const QString & title();

	signals:
		// Emitted when we have a new listener (after HTTP setup)
		void gainedConnection(IcecastClientSocket *);
		// Emitted when we've lost a connection
		void lostConnection(IcecastClientSocket *);
		void statusChange(bool);

	protected slots:
		void slotClientConnected(IcecastClientSocket *clientSocket);
		void slotClientDisconnected(IcecastClientSocket *clientSocket);

		// Called when the encoder has new data for us
		void transmitData(char *, int);
		// Called when our IcecastServerSocket has a
		// new connection
		void addSocket(int);
		// Called when our MP3Stream died unexpectedly
		// Used to shutdown the server for now
		void slotEncoderDied();

	protected:
		void shutdown();

	protected:
		// Our server socket (listens for connections)
		IcecastServerSocket *mServerSocket;
		// Our currently active sockets
		QPtrList<IcecastClientSocket> mClientSockets;
		// Our encoder wrapper
		MP3Stream *mStream;
		bool mActive;
		unsigned int mMaxClients;
		QString mTitle;
};

#endif
